core - core

#

API Docs for: 0.0.2
Show: Inherited Protected Private Deprecated

# core Class

Defined in: `src/core.js:580`
Module: core

The main module and namespace used within the core framework.

- Index
- Methods
- Properties

## Item Index

### Methods

- _import
- dependency
- guid
- inherits
- rect
- registerNamespace

### Properties

- browser
- util

## Methods

### `_import`

(

- `package`

)

Defined in `src/core.js:203`

Utility method for referencing objects within the core framework. This also adds existence checking for the objects being referenced on import.

#### Parameters:

- `package` String

  The namespace of the object being imported.

#### Returns:

Object The object being imported

### `dependency`

(

- `object`
- `message`

)

Defined in `src/core.js:226`

Utility method for performing dependency checks on core classes.

#### Parameters:

- `object` String

  The object to check if its defined.

- `message` String

  The message to display on warning when the object passed for checking is undefined.

#### Returns:

Object The object being imported

### `guid`

()

Defined in `src/core.js:108`

Utility method for generating GUID. [http://stackoverflow.com/a/873856/820640]

#### Returns:

String Returns a GUID string

### `inherits`

(

- `obj`

)

Defined in `src/core.js:12`

Utility method for implementing prototypal inheritance within the core framework.

#### Parameters:

- `obj` Object

  The object where the prototype is going to be derived from.

### `rect`

()

Defined in `src/core.js:128`

Utility method for getting the bounding rect of the dom element - also adds support for IE8

#### Returns:

Object Contains the rectangular information of a HTMLElement

### `registerNamespace`

()

Defined in `src/core.js:172`

Utility method for exposing objects in a namespaced fashion.

## Properties

### `browser`

Object

Defined in `src/core.js:96`

Store browser information based on the detection algorithm implemented within core.

### `util`

Object

Defined in `src/core.js:164`

Core utility object. Contains useful utility functions.